@@ -293,6 +293,12 @@ class ScalarField(Field):
             return {FieldPath(self.name): self}  # pylint: disable=no-member
         return {}
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, ScalarField):
+            return False
+
+        return self.__dict__ == other.__dict__
+
 
 class ObjectField(Field):
     """A field that represents a json dict structure."""
@@ -345,6 +351,15 @@ class ObjectField(Field):
             },
         )
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, ObjectField):
+            return False
+
+        print(f"{self.__dict__=}")
+        print(f"{other.__dict__=}")
+
+        return self.__dict__ == other.__dict__
+
 
 # pylint: disable=too-many-arguments
 def generate_field(
@@ -440,7 +455,7 @@ class Collection(BaseModel):
     def identities(self) -> Dict[FieldPath, Tuple[str, ...]]:
         """return identity pointers included in the table"""
         return {
-            field_path: field.identity
+            field_path: field.identity  # type: ignore
             for field_path, field in self.field_dict.items()
             if field.identity
         }
