@@ -6,7 +6,7 @@ from typing import Any, Dict, Generic, List, Optional, Tuple, TypeVar
 import pydash
 from sqlalchemy import MetaData, Table, text
 from sqlalchemy.engine import Engine
-from sqlalchemy.sql import Executable, Update
+from sqlalchemy.sql import Executable, Update  # type: ignore
 from sqlalchemy.sql.elements import ColumnElement, TextClause
 
 from fidesops.graph.config import (
@@ -18,7 +18,7 @@ from fidesops.graph.config import (
 )
 from fidesops.graph.traversal import Row, TraversalNode
 from fidesops.models.policy import ActionType, Policy, Rule
-from fidesops.models.privacy_request import PrivacyRequest
+from fidesops.models.privacy_request import ManualAction, PrivacyRequest
 from fidesops.service.masking.strategy.masking_strategy import MaskingStrategy
 from fidesops.service.masking.strategy.masking_strategy_factory import (
     MaskingStrategyFactory,
@@ -240,7 +240,7 @@ class QueryConfig(Generic[T], ABC):
         returns None"""
 
     @abstractmethod
-    def query_to_str(self, t: T, input_data: Dict[str, List[Any]]) -> str:
+    def query_to_str(self, t: T, input_data: Dict[str, List[Any]]) -> Optional[str]:
         """Convert query to string"""
 
     @abstractmethod
@@ -256,6 +256,86 @@ class QueryConfig(Generic[T], ABC):
         returns None"""
 
 
+class ManualQueryConfig(QueryConfig[Executable]):
+    def generate_query(
+        self, input_data: Dict[str, List[Any]], policy: Optional[Policy]
+    ) -> Optional[ManualAction]:
+        """Describe the details needed to manually retrieve data from the
+        current collection.
+
+        Example:
+        {
+            "step": "access",
+            "collection": "manual_dataset:manual_collection",
+            "action_needed": [
+                {
+                    "locators": {'email': "customer-1@example.com"},
+                    "get": ["id", "box_id"]
+                    "update":  {}
+                }
+            ]
+        }
+
+        """
+
+        locators: Dict[str, Any] = self.node.typed_filtered_values(input_data)
+        get: List[str] = [
+            field_path.string_path
+            for field_path in self.node.node.collection.top_level_field_dict
+        ]
+
+        if get and locators:
+            return ManualAction(locators=locators, get=get, update=None)
+        return None
+
+    def query_to_str(self, t: T, input_data: Dict[str, List[Any]]) -> None:
+        """Not used for ManualQueryConfig, we output the dry run query as a dictionary instead of a string"""
+
+    def dry_run_query(self) -> Optional[ManualAction]:
+        """Displays the ManualAction needed with question marks instead of action data for the locators
+        as a dry run query"""
+        fake_data: Dict[str, Any] = self.display_query_data()
+        manual_query: Optional[ManualAction] = self.generate_query(fake_data, None)
+        if not manual_query:
+            return None
+
+        for where_params in manual_query.locators.values():
+            for i, _ in enumerate(where_params):
+                where_params[i] = "?"
+        return manual_query
+
+    def generate_update_stmt(
+        self, row: Row, policy: Policy, request: PrivacyRequest
+    ) -> Optional[ManualAction]:
+        """Describe the details needed to manually mask data in the
+        current collection.
+
+        Example:
+         {
+            "step": "erasure",
+            "collection": "manual_dataset:manual_collection",
+            "action_needed": [
+                {
+                    "locators": {'id': 1},
+                    "get": []
+                    "update":  {'authorized_user': None}
+                }
+            ]
+        }
+        """
+        locators: Dict[str, Any] = filter_nonempty_values(
+            {
+                field_path.string_path: field.cast(row[field_path.string_path])
+                for field_path, field in self.primary_key_field_paths.items()
+            }
+        )
+        update_stmt: Dict[str, Any] = self.update_value_map(row, policy, request)
+
+        if update_stmt and locators:
+            return ManualAction(locators=locators, get=None, update=update_stmt)
+        return None
+
+
 class SQLQueryConfig(QueryConfig[Executable]):
     """Query config that translates parameters into SQL statements."""
 
@@ -567,7 +647,7 @@ class BigQueryQueryConfig(QueryStringWithoutTuplesOverrideQueryConfig):
             }
         )
 
-        valid = len(non_empty_primary_keys) > 0
+        valid = len(non_empty_primary_keys) > 0 and update_value_map
         if not valid:
             logger.warning(
                 f"There is not enough data to generate a valid update statement for {self.node.address}"
